# coding: utf-8

"""
    Hydrogen Proton API

    Financial engineering module of Hydrogen Atom  # noqa: E501

    OpenAPI spec version: 1.8.0
    Contact: info@hydrogenplatform.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class RiskAllocationRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'market_data_source': 'str',
        'allocations': 'list[str]',
        'client_id': 'str',
        'opt_config': 'OptConfig',
        'risk_score': 'float',
        'use_proxy_data': 'bool',
        'allocation_method': 'str'
    }

    attribute_map = {
        'market_data_source': 'market_data_source',
        'allocations': 'allocations',
        'client_id': 'client_id',
        'opt_config': 'opt_config',
        'risk_score': 'risk_score',
        'use_proxy_data': 'use_proxy_data',
        'allocation_method': 'allocation_method'
    }

    def __init__(self, market_data_source='nucleus', allocations=None, client_id=None, opt_config=None, risk_score=None, use_proxy_data=False, allocation_method=None):  # noqa: E501
        """RiskAllocationRequest - a model defined in Swagger"""  # noqa: E501

        self._market_data_source = None
        self._allocations = None
        self._client_id = None
        self._opt_config = None
        self._risk_score = None
        self._use_proxy_data = None
        self._allocation_method = None
        self.discriminator = None

        if market_data_source is not None:
            self.market_data_source = market_data_source
        if allocations is not None:
            self.allocations = allocations
        if client_id is not None:
            self.client_id = client_id
        if opt_config is not None:
            self.opt_config = opt_config
        if risk_score is not None:
            self.risk_score = risk_score
        if use_proxy_data is not None:
            self.use_proxy_data = use_proxy_data
        self.allocation_method = allocation_method

    @property
    def market_data_source(self):
        """Gets the market_data_source of this RiskAllocationRequest.  # noqa: E501


        :return: The market_data_source of this RiskAllocationRequest.  # noqa: E501
        :rtype: str
        """
        return self._market_data_source

    @market_data_source.setter
    def market_data_source(self, market_data_source):
        """Sets the market_data_source of this RiskAllocationRequest.


        :param market_data_source: The market_data_source of this RiskAllocationRequest.  # noqa: E501
        :type: str
        """
        allowed_values = ["nucleus", "integration"]  # noqa: E501
        if market_data_source not in allowed_values:
            raise ValueError(
                "Invalid value for `market_data_source` ({0}), must be one of {1}"  # noqa: E501
                .format(market_data_source, allowed_values)
            )

        self._market_data_source = market_data_source

    @property
    def allocations(self):
        """Gets the allocations of this RiskAllocationRequest.  # noqa: E501


        :return: The allocations of this RiskAllocationRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._allocations

    @allocations.setter
    def allocations(self, allocations):
        """Sets the allocations of this RiskAllocationRequest.


        :param allocations: The allocations of this RiskAllocationRequest.  # noqa: E501
        :type: list[str]
        """

        self._allocations = allocations

    @property
    def client_id(self):
        """Gets the client_id of this RiskAllocationRequest.  # noqa: E501


        :return: The client_id of this RiskAllocationRequest.  # noqa: E501
        :rtype: str
        """
        return self._client_id

    @client_id.setter
    def client_id(self, client_id):
        """Sets the client_id of this RiskAllocationRequest.


        :param client_id: The client_id of this RiskAllocationRequest.  # noqa: E501
        :type: str
        """

        self._client_id = client_id

    @property
    def opt_config(self):
        """Gets the opt_config of this RiskAllocationRequest.  # noqa: E501


        :return: The opt_config of this RiskAllocationRequest.  # noqa: E501
        :rtype: OptConfig
        """
        return self._opt_config

    @opt_config.setter
    def opt_config(self, opt_config):
        """Sets the opt_config of this RiskAllocationRequest.


        :param opt_config: The opt_config of this RiskAllocationRequest.  # noqa: E501
        :type: OptConfig
        """

        self._opt_config = opt_config

    @property
    def risk_score(self):
        """Gets the risk_score of this RiskAllocationRequest.  # noqa: E501


        :return: The risk_score of this RiskAllocationRequest.  # noqa: E501
        :rtype: float
        """
        return self._risk_score

    @risk_score.setter
    def risk_score(self, risk_score):
        """Sets the risk_score of this RiskAllocationRequest.


        :param risk_score: The risk_score of this RiskAllocationRequest.  # noqa: E501
        :type: float
        """
        if risk_score is not None and risk_score > 100:  # noqa: E501
            raise ValueError("Invalid value for `risk_score`, must be a value less than or equal to `100`")  # noqa: E501
        if risk_score is not None and risk_score < 0:  # noqa: E501
            raise ValueError("Invalid value for `risk_score`, must be a value greater than or equal to `0`")  # noqa: E501

        self._risk_score = risk_score

    @property
    def use_proxy_data(self):
        """Gets the use_proxy_data of this RiskAllocationRequest.  # noqa: E501


        :return: The use_proxy_data of this RiskAllocationRequest.  # noqa: E501
        :rtype: bool
        """
        return self._use_proxy_data

    @use_proxy_data.setter
    def use_proxy_data(self, use_proxy_data):
        """Sets the use_proxy_data of this RiskAllocationRequest.


        :param use_proxy_data: The use_proxy_data of this RiskAllocationRequest.  # noqa: E501
        :type: bool
        """

        self._use_proxy_data = use_proxy_data

    @property
    def allocation_method(self):
        """Gets the allocation_method of this RiskAllocationRequest.  # noqa: E501


        :return: The allocation_method of this RiskAllocationRequest.  # noqa: E501
        :rtype: str
        """
        return self._allocation_method

    @allocation_method.setter
    def allocation_method(self, allocation_method):
        """Sets the allocation_method of this RiskAllocationRequest.


        :param allocation_method: The allocation_method of this RiskAllocationRequest.  # noqa: E501
        :type: str
        """
        if allocation_method is None:
            raise ValueError("Invalid value for `allocation_method`, must not be `None`")  # noqa: E501
        allowed_values = ["select", "create"]  # noqa: E501
        if allocation_method not in allowed_values:
            raise ValueError(
                "Invalid value for `allocation_method` ({0}), must be one of {1}"  # noqa: E501
                .format(allocation_method, allowed_values)
            )

        self._allocation_method = allocation_method

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(RiskAllocationRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RiskAllocationRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Hydrogen Proton API

    Financial engineering module of Hydrogen Atom  # noqa: E501

    OpenAPI spec version: 1.8.0
    Contact: info@hydrogenplatform.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import proton_api
from proton_api.api.simulations_api import SimulationsApi  # noqa: E501
from proton_api.rest import ApiException


class TestSimulationsApi(unittest.TestCase):
    """SimulationsApi unit test stubs"""

    def setUp(self):
        self.api = proton_api.api.simulations_api.SimulationsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_backtest(self):
        """Test case for backtest

        Backtest  # noqa: E501
        """
        pass

    def test_event_study(self):
        """Test case for event_study

        Event Study  # noqa: E501
        """
        pass

    def test_monte_carlo(self):
        """Test case for monte_carlo

        Monte Carlo  # noqa: E501
        """
        pass

    def test_portfolio_what_if(self):
        """Test case for portfolio_what_if

        Porfolio What-If  # noqa: E501
        """
        pass

    def test_savings_calculator(self):
        """Test case for savings_calculator

        Savings Calculator  # noqa: E501
        """
        pass

    def test_scenario_analysis(self):
        """Test case for scenario_analysis

        Scenario Analysis  # noqa: E501
        """
        pass

    def test_sensitivity_analysis(self):
        """Test case for sensitivity_analysis

        Sensitivity Analysis  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Hydrogen Proton API

    Financial engineering module of Hydrogen Atom  # noqa: E501

    OpenAPI spec version: 1.8.0
    Contact: info@hydrogenplatform.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import proton_api
from proton_api.models.education_calculator_deposit_amount_request import EducationCalculatorDepositAmountRequest  # noqa: E501
from proton_api.rest import ApiException


class TestEducationCalculatorDepositAmountRequest(unittest.TestCase):
    """EducationCalculatorDepositAmountRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testEducationCalculatorDepositAmountRequest(self):
        """Test EducationCalculatorDepositAmountRequest"""
        # FIXME: construct object with mandatory attributes with example values
        # model = proton_api.models.education_calculator_deposit_amount_request.EducationCalculatorDepositAmountRequest()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Hydrogen Proton API

    Financial engineering module of Hydrogen Atom  # noqa: E501

    OpenAPI spec version: 1.8.0
    Contact: info@hydrogenplatform.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from proton_api.api_client import ApiClient


class PersonalFinancialManagementApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def budget_calculator(self, budget_calculator_request, **kwargs):  # noqa: E501
        """Budget Calculator  # noqa: E501

        Analyze spending against a defined budget  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.budget_calculator(budget_calculator_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param BudgetCalculatorRequest budget_calculator_request: Request payload for Budget Calculator (required)
        :return: dict(str, object)
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.budget_calculator_with_http_info(budget_calculator_request, **kwargs)  # noqa: E501
        else:
            (data) = self.budget_calculator_with_http_info(budget_calculator_request, **kwargs)  # noqa: E501
            return data

    def budget_calculator_with_http_info(self, budget_calculator_request, **kwargs):  # noqa: E501
        """Budget Calculator  # noqa: E501

        Analyze spending against a defined budget  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.budget_calculator_with_http_info(budget_calculator_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param BudgetCalculatorRequest budget_calculator_request: Request payload for Budget Calculator (required)
        :return: dict(str, object)
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['budget_calculator_request']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method budget_calculator" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'budget_calculator_request' is set
        if ('budget_calculator_request' not in params or
                params['budget_calculator_request'] is None):
            raise ValueError("Missing the required parameter `budget_calculator_request` when calling `budget_calculator`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'budget_calculator_request' in params:
            body_params = params['budget_calculator_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['oauth2']  # noqa: E501

        return self.api_client.call_api(
            '/budget_calculator', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='dict(str, object)',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def cash_flow_analysis(self, cash_flow_analysis_request, **kwargs):  # noqa: E501
        """Cash Flow Analysis  # noqa: E501

        Analyze income, expenses, and net income  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.cash_flow_analysis(cash_flow_analysis_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CashFlowAnalysisRequest cash_flow_analysis_request: Request payload for Cash Flow Analysis (required)
        :return: dict(str, object)
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.cash_flow_analysis_with_http_info(cash_flow_analysis_request, **kwargs)  # noqa: E501
        else:
            (data) = self.cash_flow_analysis_with_http_info(cash_flow_analysis_request, **kwargs)  # noqa: E501
            return data

    def cash_flow_analysis_with_http_info(self, cash_flow_analysis_request, **kwargs):  # noqa: E501
        """Cash Flow Analysis  # noqa: E501

        Analyze income, expenses, and net income  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.cash_flow_analysis_with_http_info(cash_flow_analysis_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CashFlowAnalysisRequest cash_flow_analysis_request: Request payload for Cash Flow Analysis (required)
        :return: dict(str, object)
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['cash_flow_analysis_request']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method cash_flow_analysis" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'cash_flow_analysis_request' is set
        if ('cash_flow_analysis_request' not in params or
                params['cash_flow_analysis_request'] is None):
            raise ValueError("Missing the required parameter `cash_flow_analysis_request` when calling `cash_flow_analysis`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'cash_flow_analysis_request' in params:
            body_params = params['cash_flow_analysis_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['oauth2']  # noqa: E501

        return self.api_client.call_api(
            '/cash_flow_analysis', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='dict(str, object)',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def fee_analysis(self, fee_analysis_request, **kwargs):  # noqa: E501
        """RFee Analysis  # noqa: E501

        Analyze fee data  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.fee_analysis(fee_analysis_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param FeeAnalysisRequest fee_analysis_request: Request payload for Fee Analysis (required)
        :return: dict(str, object)
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.fee_analysis_with_http_info(fee_analysis_request, **kwargs)  # noqa: E501
        else:
            (data) = self.fee_analysis_with_http_info(fee_analysis_request, **kwargs)  # noqa: E501
            return data

    def fee_analysis_with_http_info(self, fee_analysis_request, **kwargs):  # noqa: E501
        """RFee Analysis  # noqa: E501

        Analyze fee data  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.fee_analysis_with_http_info(fee_analysis_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param FeeAnalysisRequest fee_analysis_request: Request payload for Fee Analysis (required)
        :return: dict(str, object)
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['fee_analysis_request']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method fee_analysis" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'fee_analysis_request' is set
        if ('fee_analysis_request' not in params or
                params['fee_analysis_request'] is None):
            raise ValueError("Missing the required parameter `fee_analysis_request` when calling `fee_analysis`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'fee_analysis_request' in params:
            body_params = params['fee_analysis_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['oauth2']  # noqa: E501

        return self.api_client.call_api(
            '/fee_analysis', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='dict(str, object)',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def financial_picture(self, financial_picture_request, **kwargs):  # noqa: E501
        """Financial Picture  # noqa: E501

        Assess assets, liabilities, and net worth  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.financial_picture(financial_picture_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param FinancialPictureRequest financial_picture_request: Request payload for Financial Picture (required)
        :return: dict(str, object)
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.financial_picture_with_http_info(financial_picture_request, **kwargs)  # noqa: E501
        else:
            (data) = self.financial_picture_with_http_info(financial_picture_request, **kwargs)  # noqa: E501
            return data

    def financial_picture_with_http_info(self, financial_picture_request, **kwargs):  # noqa: E501
        """Financial Picture  # noqa: E501

        Assess assets, liabilities, and net worth  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.financial_picture_with_http_info(financial_picture_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param FinancialPictureRequest financial_picture_request: Request payload for Financial Picture (required)
        :return: dict(str, object)
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['financial_picture_request']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method financial_picture" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'financial_picture_request' is set
        if ('financial_picture_request' not in params or
                params['financial_picture_request'] is None):
            raise ValueError("Missing the required parameter `financial_picture_request` when calling `financial_picture`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'financial_picture_request' in params:
            body_params = params['financial_picture_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['oauth2']  # noqa: E501

        return self.api_client.call_api(
            '/financial_picture', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='dict(str, object)',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def recurring_transaction_analysis(self, recurring_transaction_analysis_request, **kwargs):  # noqa: E501
        """Recurring Transaction Analysis  # noqa: E501

        Analyze recurring transactions  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.recurring_transaction_analysis(recurring_transaction_analysis_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param RecurringTransactionAnalysisRequest recurring_transaction_analysis_request: Request payload for Recurring Transaction Analysis (required)
        :return: dict(str, object)
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.recurring_transaction_analysis_with_http_info(recurring_transaction_analysis_request, **kwargs)  # noqa: E501
        else:
            (data) = self.recurring_transaction_analysis_with_http_info(recurring_transaction_analysis_request, **kwargs)  # noqa: E501
            return data

    def recurring_transaction_analysis_with_http_info(self, recurring_transaction_analysis_request, **kwargs):  # noqa: E501
        """Recurring Transaction Analysis  # noqa: E501

        Analyze recurring transactions  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.recurring_transaction_analysis_with_http_info(recurring_transaction_analysis_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param RecurringTransactionAnalysisRequest recurring_transaction_analysis_request: Request payload for Recurring Transaction Analysis (required)
        :return: dict(str, object)
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['recurring_transaction_analysis_request']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method recurring_transaction_analysis" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'recurring_transaction_analysis_request' is set
        if ('recurring_transaction_analysis_request' not in params or
                params['recurring_transaction_analysis_request'] is None):
            raise ValueError("Missing the required parameter `recurring_transaction_analysis_request` when calling `recurring_transaction_analysis`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'recurring_transaction_analysis_request' in params:
            body_params = params['recurring_transaction_analysis_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['oauth2']  # noqa: E501

        return self.api_client.call_api(
            '/recurring_transaction_analysis', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='dict(str, object)',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from proton_api.api.annuities_api import AnnuitiesApi
from proton_api.api.business_financial_management_api import BusinessFinancialManagementApi
from proton_api.api.cards_api import CardsApi
from proton_api.api.financial_health_api import FinancialHealthApi
from proton_api.api.financial_planning_api import FinancialPlanningApi
from proton_api.api.goals_api import GoalsApi
from proton_api.api.life_insurance_api import LifeInsuranceApi
from proton_api.api.personal_financial_management_api import PersonalFinancialManagementApi
from proton_api.api.portfolio_construction_api import PortfolioConstructionApi
from proton_api.api.portfolio_management_api import PortfolioManagementApi
from proton_api.api.risk_scoring_api import RiskScoringApi
from proton_api.api.simulations_api import SimulationsApi



# coding: utf-8

"""
    Hydrogen Proton API

    Financial engineering module of Hydrogen Atom  # noqa: E501

    OpenAPI spec version: 1.8.0
    Contact: info@hydrogenplatform.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import proton_api
from proton_api.api.financial_planning_api import FinancialPlanningApi  # noqa: E501
from proton_api.rest import ApiException


class TestFinancialPlanningApi(unittest.TestCase):
    """FinancialPlanningApi unit test stubs"""

    def setUp(self):
        self.api = proton_api.api.financial_planning_api.FinancialPlanningApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_education_calculator_annual_cost(self):
        """Test case for education_calculator_annual_cost

        Education Calculator - Annual Cost  # noqa: E501
        """
        pass

    def test_education_calculator_deposit_amount(self):
        """Test case for education_calculator_deposit_amount

        Education Calculator - Deposit Amount  # noqa: E501
        """
        pass

    def test_education_calculator_percent_covered(self):
        """Test case for education_calculator_percent_covered

        Education Calculator - Percent Covered  # noqa: E501
        """
        pass

    def test_mortgage_calculator_down_payment(self):
        """Test case for mortgage_calculator_down_payment

        Mortgage Calculator - Down Payment  # noqa: E501
        """
        pass

    def test_mortgage_calculator_home_price(self):
        """Test case for mortgage_calculator_home_price

        Mortgage Calculator - Home Price  # noqa: E501
        """
        pass

    def test_mortgage_calculator_periodic_payment(self):
        """Test case for mortgage_calculator_periodic_payment

        Mortgage Calculator - Periodic Payment  # noqa: E501
        """
        pass

    def test_purchase_calculator_amount(self):
        """Test case for purchase_calculator_amount

        Purchase Calculator - Amount  # noqa: E501
        """
        pass

    def test_purchase_calculator_deposit_amount(self):
        """Test case for purchase_calculator_deposit_amount

        Purchase Calculator - Deposit Amount  # noqa: E501
        """
        pass

    def test_purchase_calculator_horizon(self):
        """Test case for purchase_calculator_horizon

        Purchase Calculator - Horizon  # noqa: E501
        """
        pass

    def test_retirement_calculator_deposit_amount(self):
        """Test case for retirement_calculator_deposit_amount

        Retirement Calculator - Deposit Amount  # noqa: E501
        """
        pass

    def test_retirement_calculator_expenses(self):
        """Test case for retirement_calculator_expenses

        Retirement Calculator - Expenses  # noqa: E501
        """
        pass

    def test_retirement_calculator_percent_covered(self):
        """Test case for retirement_calculator_percent_covered

        Retirement Calculator - Percent Covered  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Hydrogen Proton API

    Financial engineering module of Hydrogen Atom  # noqa: E501

    OpenAPI spec version: 1.8.0
    Contact: info@hydrogenplatform.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class BacktestRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'asset_size': 'float',
        'end_date': 'date',
        'stats': 'bool',
        'asset_sizes': 'bool',
        'model_id': 'str',
        'initial_weights': 'object',
        'trades': 'bool',
        'start_date': 'date',
        'settings': 'Settings',
        'holdings': 'bool'
    }

    attribute_map = {
        'asset_size': 'asset_size',
        'end_date': 'end_date',
        'stats': 'stats',
        'asset_sizes': 'asset_sizes',
        'model_id': 'model_id',
        'initial_weights': 'initial_weights',
        'trades': 'trades',
        'start_date': 'start_date',
        'settings': 'settings',
        'holdings': 'holdings'
    }

    def __init__(self, asset_size=None, end_date=None, stats=True, asset_sizes=True, model_id=None, initial_weights=None, trades=True, start_date=None, settings=None, holdings=True):  # noqa: E501
        """BacktestRequest - a model defined in Swagger"""  # noqa: E501

        self._asset_size = None
        self._end_date = None
        self._stats = None
        self._asset_sizes = None
        self._model_id = None
        self._initial_weights = None
        self._trades = None
        self._start_date = None
        self._settings = None
        self._holdings = None
        self.discriminator = None

        if asset_size is not None:
            self.asset_size = asset_size
        self.end_date = end_date
        if stats is not None:
            self.stats = stats
        if asset_sizes is not None:
            self.asset_sizes = asset_sizes
        if model_id is not None:
            self.model_id = model_id
        if initial_weights is not None:
            self.initial_weights = initial_weights
        if trades is not None:
            self.trades = trades
        self.start_date = start_date
        if settings is not None:
            self.settings = settings
        if holdings is not None:
            self.holdings = holdings

    @property
    def asset_size(self):
        """Gets the asset_size of this BacktestRequest.  # noqa: E501


        :return: The asset_size of this BacktestRequest.  # noqa: E501
        :rtype: float
        """
        return self._asset_size

    @asset_size.setter
    def asset_size(self, asset_size):
        """Sets the asset_size of this BacktestRequest.


        :param asset_size: The asset_size of this BacktestRequest.  # noqa: E501
        :type: float
        """
        if asset_size is not None and asset_size < 0:  # noqa: E501
            raise ValueError("Invalid value for `asset_size`, must be a value greater than or equal to `0`")  # noqa: E501

        self._asset_size = asset_size

    @property
    def end_date(self):
        """Gets the end_date of this BacktestRequest.  # noqa: E501


        :return: The end_date of this BacktestRequest.  # noqa: E501
        :rtype: date
        """
        return self._end_date

    @end_date.setter
    def end_date(self, end_date):
        """Sets the end_date of this BacktestRequest.


        :param end_date: The end_date of this BacktestRequest.  # noqa: E501
        :type: date
        """
        if end_date is None:
            raise ValueError("Invalid value for `end_date`, must not be `None`")  # noqa: E501

        self._end_date = end_date

    @property
    def stats(self):
        """Gets the stats of this BacktestRequest.  # noqa: E501


        :return: The stats of this BacktestRequest.  # noqa: E501
        :rtype: bool
        """
        return self._stats

    @stats.setter
    def stats(self, stats):
        """Sets the stats of this BacktestRequest.


        :param stats: The stats of this BacktestRequest.  # noqa: E501
        :type: bool
        """

        self._stats = stats

    @property
    def asset_sizes(self):
        """Gets the asset_sizes of this BacktestRequest.  # noqa: E501


        :return: The asset_sizes of this BacktestRequest.  # noqa: E501
        :rtype: bool
        """
        return self._asset_sizes

    @asset_sizes.setter
    def asset_sizes(self, asset_sizes):
        """Sets the asset_sizes of this BacktestRequest.


        :param asset_sizes: The asset_sizes of this BacktestRequest.  # noqa: E501
        :type: bool
        """

        self._asset_sizes = asset_sizes

    @property
    def model_id(self):
        """Gets the model_id of this BacktestRequest.  # noqa: E501


        :return: The model_id of this BacktestRequest.  # noqa: E501
        :rtype: str
        """
        return self._model_id

    @model_id.setter
    def model_id(self, model_id):
        """Sets the model_id of this BacktestRequest.


        :param model_id: The model_id of this BacktestRequest.  # noqa: E501
        :type: str
        """

        self._model_id = model_id

    @property
    def initial_weights(self):
        """Gets the initial_weights of this BacktestRequest.  # noqa: E501


        :return: The initial_weights of this BacktestRequest.  # noqa: E501
        :rtype: object
        """
        return self._initial_weights

    @initial_weights.setter
    def initial_weights(self, initial_weights):
        """Sets the initial_weights of this BacktestRequest.


        :param initial_weights: The initial_weights of this BacktestRequest.  # noqa: E501
        :type: object
        """

        self._initial_weights = initial_weights

    @property
    def trades(self):
        """Gets the trades of this BacktestRequest.  # noqa: E501


        :return: The trades of this BacktestRequest.  # noqa: E501
        :rtype: bool
        """
        return self._trades

    @trades.setter
    def trades(self, trades):
        """Sets the trades of this BacktestRequest.


        :param trades: The trades of this BacktestRequest.  # noqa: E501
        :type: bool
        """

        self._trades = trades

    @property
    def start_date(self):
        """Gets the start_date of this BacktestRequest.  # noqa: E501


        :return: The start_date of this BacktestRequest.  # noqa: E501
        :rtype: date
        """
        return self._start_date

    @start_date.setter
    def start_date(self, start_date):
        """Sets the start_date of this BacktestRequest.


        :param start_date: The start_date of this BacktestRequest.  # noqa: E501
        :type: date
        """
        if start_date is None:
            raise ValueError("Invalid value for `start_date`, must not be `None`")  # noqa: E501

        self._start_date = start_date

    @property
    def settings(self):
        """Gets the settings of this BacktestRequest.  # noqa: E501


        :return: The settings of this BacktestRequest.  # noqa: E501
        :rtype: Settings
        """
        return self._settings

    @settings.setter
    def settings(self, settings):
        """Sets the settings of this BacktestRequest.


        :param settings: The settings of this BacktestRequest.  # noqa: E501
        :type: Settings
        """

        self._settings = settings

    @property
    def holdings(self):
        """Gets the holdings of this BacktestRequest.  # noqa: E501


        :return: The holdings of this BacktestRequest.  # noqa: E501
        :rtype: bool
        """
        return self._holdings

    @holdings.setter
    def holdings(self, holdings):
        """Sets the holdings of this BacktestRequest.


        :param holdings: The holdings of this BacktestRequest.  # noqa: E501
        :type: bool
        """

        self._holdings = holdings

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(BacktestRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BacktestRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Hydrogen Proton API

    Financial engineering module of Hydrogen Atom  # noqa: E501

    OpenAPI spec version: 1.8.0
    Contact: info@hydrogenplatform.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import proton_api
from proton_api.api.risk_scoring_api import RiskScoringApi  # noqa: E501
from proton_api.rest import ApiException


class TestRiskScoringApi(unittest.TestCase):
    """RiskScoringApi unit test stubs"""

    def setUp(self):
        self.api = proton_api.api.risk_scoring_api.RiskScoringApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_dimensional_risk_score(self):
        """Test case for dimensional_risk_score

        Dimensional Risk Score  # noqa: E501
        """
        pass

    def test_risk_allocation(self):
        """Test case for risk_allocation

        Risk Allocation  # noqa: E501
        """
        pass

    def test_risk_score(self):
        """Test case for risk_score

        Risk Score  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Hydrogen Proton API

    Financial engineering module of Hydrogen Atom  # noqa: E501

    OpenAPI spec version: 1.8.0
    Contact: info@hydrogenplatform.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class MortgageCalculatorPeriodicPaymentRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'mortgage_term': 'int',
        'home_price': 'float',
        'down_payment': 'float',
        'interest_rate': 'float'
    }

    attribute_map = {
        'mortgage_term': 'mortgage_term',
        'home_price': 'home_price',
        'down_payment': 'down_payment',
        'interest_rate': 'interest_rate'
    }

    def __init__(self, mortgage_term=360, home_price=None, down_payment=None, interest_rate=0.04):  # noqa: E501
        """MortgageCalculatorPeriodicPaymentRequest - a model defined in Swagger"""  # noqa: E501

        self._mortgage_term = None
        self._home_price = None
        self._down_payment = None
        self._interest_rate = None
        self.discriminator = None

        if mortgage_term is not None:
            self.mortgage_term = mortgage_term
        self.home_price = home_price
        self.down_payment = down_payment
        if interest_rate is not None:
            self.interest_rate = interest_rate

    @property
    def mortgage_term(self):
        """Gets the mortgage_term of this MortgageCalculatorPeriodicPaymentRequest.  # noqa: E501


        :return: The mortgage_term of this MortgageCalculatorPeriodicPaymentRequest.  # noqa: E501
        :rtype: int
        """
        return self._mortgage_term

    @mortgage_term.setter
    def mortgage_term(self, mortgage_term):
        """Sets the mortgage_term of this MortgageCalculatorPeriodicPaymentRequest.


        :param mortgage_term: The mortgage_term of this MortgageCalculatorPeriodicPaymentRequest.  # noqa: E501
        :type: int
        """
        if mortgage_term is not None and mortgage_term > 600:  # noqa: E501
            raise ValueError("Invalid value for `mortgage_term`, must be a value less than or equal to `600`")  # noqa: E501
        if mortgage_term is not None and mortgage_term < 0:  # noqa: E501
            raise ValueError("Invalid value for `mortgage_term`, must be a value greater than or equal to `0`")  # noqa: E501

        self._mortgage_term = mortgage_term

    @property
    def home_price(self):
        """Gets the home_price of this MortgageCalculatorPeriodicPaymentRequest.  # noqa: E501


        :return: The home_price of this MortgageCalculatorPeriodicPaymentRequest.  # noqa: E501
        :rtype: float
        """
        return self._home_price

    @home_price.setter
    def home_price(self, home_price):
        """Sets the home_price of this MortgageCalculatorPeriodicPaymentRequest.


        :param home_price: The home_price of this MortgageCalculatorPeriodicPaymentRequest.  # noqa: E501
        :type: float
        """
        if home_price is None:
            raise ValueError("Invalid value for `home_price`, must not be `None`")  # noqa: E501
        if home_price is not None and home_price < 0:  # noqa: E501
            raise ValueError("Invalid value for `home_price`, must be a value greater than or equal to `0`")  # noqa: E501

        self._home_price = home_price

    @property
    def down_payment(self):
        """Gets the down_payment of this MortgageCalculatorPeriodicPaymentRequest.  # noqa: E501


        :return: The down_payment of this MortgageCalculatorPeriodicPaymentRequest.  # noqa: E501
        :rtype: float
        """
        return self._down_payment

    @down_payment.setter
    def down_payment(self, down_payment):
        """Sets the down_payment of this MortgageCalculatorPeriodicPaymentRequest.


        :param down_payment: The down_payment of this MortgageCalculatorPeriodicPaymentRequest.  # noqa: E501
        :type: float
        """
        if down_payment is None:
            raise ValueError("Invalid value for `down_payment`, must not be `None`")  # noqa: E501
        if down_payment is not None and down_payment < 0:  # noqa: E501
            raise ValueError("Invalid value for `down_payment`, must be a value greater than or equal to `0`")  # noqa: E501

        self._down_payment = down_payment

    @property
    def interest_rate(self):
        """Gets the interest_rate of this MortgageCalculatorPeriodicPaymentRequest.  # noqa: E501


        :return: The interest_rate of this MortgageCalculatorPeriodicPaymentRequest.  # noqa: E501
        :rtype: float
        """
        return self._interest_rate

    @interest_rate.setter
    def interest_rate(self, interest_rate):
        """Sets the interest_rate of this MortgageCalculatorPeriodicPaymentRequest.


        :param interest_rate: The interest_rate of this MortgageCalculatorPeriodicPaymentRequest.  # noqa: E501
        :type: float
        """
        if interest_rate is not None and interest_rate < 0:  # noqa: E501
            raise ValueError("Invalid value for `interest_rate`, must be a value greater than or equal to `0`")  # noqa: E501

        self._interest_rate = interest_rate

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(MortgageCalculatorPeriodicPaymentRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MortgageCalculatorPeriodicPaymentRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Hydrogen Proton API

    Financial engineering module of Hydrogen Atom  # noqa: E501

    OpenAPI spec version: 1.8.0
    Contact: info@hydrogenplatform.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class OptConfig1(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'sec_types': 'list[str]',
        'w_config': 'WConfig1',
        'tickers': 'list[str]',
        'min_assets': 'int',
        'w_asset_config': 'object'
    }

    attribute_map = {
        'sec_types': 'sec_types',
        'w_config': 'w_config',
        'tickers': 'tickers',
        'min_assets': 'min_assets',
        'w_asset_config': 'w_asset_config'
    }

    def __init__(self, sec_types=None, w_config=None, tickers=None, min_assets=1, w_asset_config=None):  # noqa: E501
        """OptConfig1 - a model defined in Swagger"""  # noqa: E501

        self._sec_types = None
        self._w_config = None
        self._tickers = None
        self._min_assets = None
        self._w_asset_config = None
        self.discriminator = None

        if sec_types is not None:
            self.sec_types = sec_types
        if w_config is not None:
            self.w_config = w_config
        if tickers is not None:
            self.tickers = tickers
        if min_assets is not None:
            self.min_assets = min_assets
        if w_asset_config is not None:
            self.w_asset_config = w_asset_config

    @property
    def sec_types(self):
        """Gets the sec_types of this OptConfig1.  # noqa: E501


        :return: The sec_types of this OptConfig1.  # noqa: E501
        :rtype: list[str]
        """
        return self._sec_types

    @sec_types.setter
    def sec_types(self, sec_types):
        """Sets the sec_types of this OptConfig1.


        :param sec_types: The sec_types of this OptConfig1.  # noqa: E501
        :type: list[str]
        """
        allowed_values = ["major", "minor", "cash"]  # noqa: E501
        if not set(sec_types).issubset(set(allowed_values)):
            raise ValueError(
                "Invalid values for `sec_types` [{0}], must be a subset of [{1}]"  # noqa: E501
                .format(", ".join(map(str, set(sec_types) - set(allowed_values))),  # noqa: E501
                        ", ".join(map(str, allowed_values)))
            )

        self._sec_types = sec_types

    @property
    def w_config(self):
        """Gets the w_config of this OptConfig1.  # noqa: E501


        :return: The w_config of this OptConfig1.  # noqa: E501
        :rtype: WConfig1
        """
        return self._w_config

    @w_config.setter
    def w_config(self, w_config):
        """Sets the w_config of this OptConfig1.


        :param w_config: The w_config of this OptConfig1.  # noqa: E501
        :type: WConfig1
        """

        self._w_config = w_config

    @property
    def tickers(self):
        """Gets the tickers of this OptConfig1.  # noqa: E501


        :return: The tickers of this OptConfig1.  # noqa: E501
        :rtype: list[str]
        """
        return self._tickers

    @tickers.setter
    def tickers(self, tickers):
        """Sets the tickers of this OptConfig1.


        :param tickers: The tickers of this OptConfig1.  # noqa: E501
        :type: list[str]
        """

        self._tickers = tickers

    @property
    def min_assets(self):
        """Gets the min_assets of this OptConfig1.  # noqa: E501


        :return: The min_assets of this OptConfig1.  # noqa: E501
        :rtype: int
        """
        return self._min_assets

    @min_assets.setter
    def min_assets(self, min_assets):
        """Sets the min_assets of this OptConfig1.


        :param min_assets: The min_assets of this OptConfig1.  # noqa: E501
        :type: int
        """
        if min_assets is not None and min_assets < 1:  # noqa: E501
            raise ValueError("Invalid value for `min_assets`, must be a value greater than or equal to `1`")  # noqa: E501

        self._min_assets = min_assets

    @property
    def w_asset_config(self):
        """Gets the w_asset_config of this OptConfig1.  # noqa: E501


        :return: The w_asset_config of this OptConfig1.  # noqa: E501
        :rtype: object
        """
        return self._w_asset_config

    @w_asset_config.setter
    def w_asset_config(self, w_asset_config):
        """Sets the w_asset_config of this OptConfig1.


        :param w_asset_config: The w_asset_config of this OptConfig1.  # noqa: E501
        :type: object
        """

        self._w_asset_config = w_asset_config

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(OptConfig1, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OptConfig1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Hydrogen Proton API

    Financial engineering module of Hydrogen Atom  # noqa: E501

    OpenAPI spec version: 1.8.0
    Contact: info@hydrogenplatform.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import proton_api
from proton_api.api.annuities_api import AnnuitiesApi  # noqa: E501
from proton_api.rest import ApiException


class TestAnnuitiesApi(unittest.TestCase):
    """AnnuitiesApi unit test stubs"""

    def setUp(self):
        self.api = proton_api.api.annuities_api.AnnuitiesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_annuity_calculator_accumulation_horizon(self):
        """Test case for annuity_calculator_accumulation_horizon

        Annuity Calculator - Accumulation Horizon  # noqa: E501
        """
        pass

    def test_annuity_calculator_annuity_amount(self):
        """Test case for annuity_calculator_annuity_amount

        Annuity Calculator - Annuity Amount  # noqa: E501
        """
        pass

    def test_annuity_calculator_decumulation_horizon(self):
        """Test case for annuity_calculator_decumulation_horizon

        Annuity Calculator - Decumulation Horizon  # noqa: E501
        """
        pass

    def test_annuity_calculator_deposit_amount(self):
        """Test case for annuity_calculator_deposit_amount

        Annuity Calculator - Deposit Amount  # noqa: E501
        """
        pass

    def test_annuity_calculator_initial_balance(self):
        """Test case for annuity_calculator_initial_balance

        Annuity Calculator - Initial Balance  # noqa: E501
        """
        pass

    def test_variable_annuity(self):
        """Test case for variable_annuity

        Variable Annuity  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Hydrogen Proton API

    Financial engineering module of Hydrogen Atom  # noqa: E501

    OpenAPI spec version: 1.8.0
    Contact: info@hydrogenplatform.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class MonteCarloRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'portfolio_id': 'str',
        'max_sample': 'list[float]',
        'result_type': 'str',
        'ret_mod': 'list[float]',
        'remove_outliers': 'bool',
        'max_bal': 'list[float]',
        'market_data_source': 'str',
        'p': 'list[float]',
        'allocation_id': 'str',
        'use_proxy_data': 'bool',
        'aggregation_account_id': 'str',
        'init_bal': 'float',
        'min_sample': 'list[float]',
        'create_log': 'bool',
        'mu': 'list[float]',
        'account_id': 'str',
        'sigma': 'list[float]',
        'model_id': 'str',
        'n': 'int',
        'min_bal': 'list[float]',
        'frequency_interval': 'str',
        'cf': 'list[list[float]]'
    }

    attribute_map = {
        'portfolio_id': 'portfolio_id',
        'max_sample': 'max_sample',
        'result_type': 'result_type',
        'ret_mod': 'ret_mod',
        'remove_outliers': 'remove_outliers',
        'max_bal': 'max_bal',
        'market_data_source': 'market_data_source',
        'p': 'p',
        'allocation_id': 'allocation_id',
        'use_proxy_data': 'use_proxy_data',
        'aggregation_account_id': 'aggregation_account_id',
        'init_bal': 'init_bal',
        'min_sample': 'min_sample',
        'create_log': 'create_log',
        'mu': 'mu',
        'account_id': 'account_id',
        'sigma': 'sigma',
        'model_id': 'model_id',
        'n': 'n',
        'min_bal': 'min_bal',
        'frequency_interval': 'frequency_interval',
        'cf': 'cf'
    }

    def __init__(self, portfolio_id=None, max_sample=None, result_type='raw', ret_mod=None, remove_outliers=False, max_bal=None, market_data_source='nucleus', p=None, allocation_id=None, use_proxy_data=False, aggregation_account_id=None, init_bal=None, min_sample=None, create_log=False, mu=None, account_id=None, sigma=None, model_id=None, n=1000, min_bal=None, frequency_interval='year', cf=None):  # noqa: E501
        """MonteCarloRequest - a model defined in Swagger"""  # noqa: E501

        self._portfolio_id = None
        self._max_sample = None
        self._result_type = None
        self._ret_mod = None
        self._remove_outliers = None
        self._max_bal = None
        self._market_data_source = None
        self._p = None
        self._allocation_id = None
        self._use_proxy_data = None
        self._aggregation_account_id = None
        self._init_bal = None
        self._min_sample = None
        self._create_log = None
        self._mu = None
        self._account_id = None
        self._sigma = None
        self._model_id = None
        self._n = None
        self._min_bal = None
        self._frequency_interval = None
        self._cf = None
        self.discriminator = None

        if portfolio_id is not None:
            self.portfolio_id = portfolio_id
        if max_sample is not None:
            self.max_sample = max_sample
        if result_type is not None:
            self.result_type = result_type
        if ret_mod is not None:
            self.ret_mod = ret_mod
        if remove_outliers is not None:
            self.remove_outliers = remove_outliers
        if max_bal is not None:
            self.max_bal = max_bal
        if market_data_source is not None:
            self.market_data_source = market_data_source
        if p is not None:
            self.p = p
        if allocation_id is not None:
            self.allocation_id = allocation_id
        if use_proxy_data is not None:
            self.use_proxy_data = use_proxy_data
        if aggregation_account_id is not None:
            self.aggregation_account_id = aggregation_account_id
        if init_bal is not None:
            self.init_bal = init_bal
        if min_sample is not None:
            self.min_sample = min_sample
        if create_log is not None:
            self.create_log = create_log
        if mu is not None:
            self.mu = mu
        if account_id is not None:
            self.account_id = account_id
        if sigma is not None:
            self.sigma = sigma
        if model_id is not None:
            self.model_id = model_id
        if n is not None:
            self.n = n
        if min_bal is not None:
            self.min_bal = min_bal
        if frequency_interval is not None:
            self.frequency_interval = frequency_interval
        self.cf = cf

    @property
    def portfolio_id(self):
        """Gets the portfolio_id of this MonteCarloRequest.  # noqa: E501


        :return: The portfolio_id of this MonteCarloRequest.  # noqa: E501
        :rtype: str
        """
        return self._portfolio_id

    @portfolio_id.setter
    def portfolio_id(self, portfolio_id):
        """Sets the portfolio_id of this MonteCarloRequest.


        :param portfolio_id: The portfolio_id of this MonteCarloRequest.  # noqa: E501
        :type: str
        """

        self._portfolio_id = portfolio_id

    @property
    def max_sample(self):
        """Gets the max_sample of this MonteCarloRequest.  # noqa: E501


        :return: The max_sample of this MonteCarloRequest.  # noqa: E501
        :rtype: list[float]
        """
        return self._max_sample

    @max_sample.setter
    def max_sample(self, max_sample):
        """Sets the max_sample of this MonteCarloRequest.


        :param max_sample: The max_sample of this MonteCarloRequest.  # noqa: E501
        :type: list[float]
        """

        self._max_sample = max_sample

    @property
    def result_type(self):
        """Gets the result_type of this MonteCarloRequest.  # noqa: E501


        :return: The result_type of this MonteCarloRequest.  # noqa: E501
        :rtype: str
        """
        return self._result_type

    @result_type.setter
    def result_type(self, result_type):
        """Sets the result_type of this MonteCarloRequest.


        :param result_type: The result_type of this MonteCarloRequest.  # noqa: E501
        :type: str
        """
        allowed_values = ["raw", "custom", "median", "mean", "tens"]  # noqa: E501
        if result_type not in allowed_values:
            raise ValueError(
                "Invalid value for `result_type` ({0}), must be one of {1}"  # noqa: E501
                .format(result_type, allowed_values)
            )

        self._result_type = result_type

    @property
    def ret_mod(self):
        """Gets the ret_mod of this MonteCarloRequest.  # noqa: E501


        :return: The ret_mod of this MonteCarloRequest.  # noqa: E501
        :rtype: list[float]
        """
        return self._ret_mod

    @ret_mod.setter
    def ret_mod(self, ret_mod):
        """Sets the ret_mod of this MonteCarloRequest.


        :param ret_mod: The ret_mod of this MonteCarloRequest.  # noqa: E501
        :type: list[float]
        """

        self._ret_mod = ret_mod

    @property
    def remove_outliers(self):
        """Gets the remove_outliers of this MonteCarloRequest.  # noqa: E501


        :return: The remove_outliers of this MonteCarloRequest.  # noqa: E501
        :rtype: bool
        """
        return self._remove_outliers

    @remove_outliers.setter
    def remove_outliers(self, remove_outliers):
        """Sets the remove_outliers of this MonteCarloRequest.


        :param remove_outliers: The remove_outliers of this MonteCarloRequest.  # noqa: E501
        :type: bool
        """

        self._remove_outliers = remove_outliers

    @property
    def max_bal(self):
        """Gets the max_bal of this MonteCarloRequest.  # noqa: E501


        :return: The max_bal of this MonteCarloRequest.  # noqa: E501
        :rtype: list[float]
        """
        return self._max_bal

    @max_bal.setter
    def max_bal(self, max_bal):
        """Sets the max_bal of this MonteCarloRequest.


        :param max_bal: The max_bal of this MonteCarloRequest.  # noqa: E501
        :type: list[float]
        """

        self._max_bal = max_bal

    @property
    def market_data_source(self):
        """Gets the market_data_source of this MonteCarloRequest.  # noqa: E501


        :return: The market_data_source of this MonteCarloRequest.  # noqa: E501
        :rtype: str
        """
        return self._market_data_source

    @market_data_source.setter
    def market_data_source(self, market_data_source):
        """Sets the market_data_source of this MonteCarloRequest.


        :param market_data_source: The market_data_source of this MonteCarloRequest.  # noqa: E501
        :type: str
        """
        allowed_values = ["nucleus", "integration"]  # noqa: E501
        if market_data_source not in allowed_values:
            raise ValueError(
                "Invalid value for `market_data_source` ({0}), must be one of {1}"  # noqa: E501
                .format(market_data_source, allowed_values)
            )

        self._market_data_source = market_data_source

    @property
    def p(self):
        """Gets the p of this MonteCarloRequest.  # noqa: E501


        :return: The p of this MonteCarloRequest.  # noqa: E501
        :rtype: list[float]
        """
        return self._p

    @p.setter
    def p(self, p):
        """Sets the p of this MonteCarloRequest.


        :param p: The p of this MonteCarloRequest.  # noqa: E501
        :type: list[float]
        """

        self._p = p

    @property
    def allocation_id(self):
        """Gets the allocation_id of this MonteCarloRequest.  # noqa: E501


        :return: The allocation_id of this MonteCarloRequest.  # noqa: E501
        :rtype: str
        """
        return self._allocation_id

    @allocation_id.setter
    def allocation_id(self, allocation_id):
        """Sets the allocation_id of this MonteCarloRequest.


        :param allocation_id: The allocation_id of this MonteCarloRequest.  # noqa: E501
        :type: str
        """

        self._allocation_id = allocation_id

    @property
    def use_proxy_data(self):
        """Gets the use_proxy_data of this MonteCarloRequest.  # noqa: E501


        :return: The use_proxy_data of this MonteCarloRequest.  # noqa: E501
        :rtype: bool
        """
        return self._use_proxy_data

    @use_proxy_data.setter
    def use_proxy_data(self, use_proxy_data):
        """Sets the use_proxy_data of this MonteCarloRequest.


        :param use_proxy_data: The use_proxy_data of this MonteCarloRequest.  # noqa: E501
        :type: bool
        """

        self._use_proxy_data = use_proxy_data

    @property
    def aggregation_account_id(self):
        """Gets the aggregation_account_id of this MonteCarloRequest.  # noqa: E501


        :return: The aggregation_account_id of this MonteCarloRequest.  # noqa: E501
        :rtype: str
        """
        return self._aggregation_account_id

    @aggregation_account_id.setter
    def aggregation_account_id(self, aggregation_account_id):
        """Sets the aggregation_account_id of this MonteCarloRequest.


        :param aggregation_account_id: The aggregation_account_id of this MonteCarloRequest.  # noqa: E501
        :type: str
        """

        self._aggregation_account_id = aggregation_account_id

    @property
    def init_bal(self):
        """Gets the init_bal of this MonteCarloRequest.  # noqa: E501


        :return: The init_bal of this MonteCarloRequest.  # noqa: E501
        :rtype: float
        """
        return self._init_bal

    @init_bal.setter
    def init_bal(self, init_bal):
        """Sets the init_bal of this MonteCarloRequest.


        :param init_bal: The init_bal of this MonteCarloRequest.  # noqa: E501
        :type: float
        """
        if init_bal is not None and init_bal < 0:  # noqa: E501
            raise ValueError("Invalid value for `init_bal`, must be a value greater than or equal to `0`")  # noqa: E501

        self._init_bal = init_bal

    @property
    def min_sample(self):
        """Gets the min_sample of this MonteCarloRequest.  # noqa: E501


        :return: The min_sample of this MonteCarloRequest.  # noqa: E501
        :rtype: list[float]
        """
        return self._min_sample

    @min_sample.setter
    def min_sample(self, min_sample):
        """Sets the min_sample of this MonteCarloRequest.


        :param min_sample: The min_sample of this MonteCarloRequest.  # noqa: E501
        :type: list[float]
        """

        self._min_sample = min_sample

    @property
    def create_log(self):
        """Gets the create_log of this MonteCarloRequest.  # noqa: E501


        :return: The create_log of this MonteCarloRequest.  # noqa: E501
        :rtype: bool
        """
        return self._create_log

    @create_log.setter
    def create_log(self, create_log):
        """Sets the create_log of this MonteCarloRequest.


        :param create_log: The create_log of this MonteCarloRequest.  # noqa: E501
        :type: bool
        """

        self._create_log = create_log

    @property
    def mu(self):
        """Gets the mu of this MonteCarloRequest.  # noqa: E501


        :return: The mu of this MonteCarloRequest.  # noqa: E501
        :rtype: list[float]
        """
        return self._mu

    @mu.setter
    def mu(self, mu):
        """Sets the mu of this MonteCarloRequest.


        :param mu: The mu of this MonteCarloRequest.  # noqa: E501
        :type: list[float]
        """

        self._mu = mu

    @property
    def account_id(self):
        """Gets the account_id of this MonteCarloRequest.  # noqa: E501


        :return: The account_id of this MonteCarloRequest.  # noqa: E501
        :rtype: str
        """
        return self._account_id

    @account_id.setter
    def account_id(self, account_id):
        """Sets the account_id of this MonteCarloRequest.


        :param account_id: The account_id of this MonteCarloRequest.  # noqa: E501
        :type: str
        """

        self._account_id = account_id

    @property
    def sigma(self):
        """Gets the sigma of this MonteCarloRequest.  # noqa: E501


        :return: The sigma of this MonteCarloRequest.  # noqa: E501
        :rtype: list[float]
        """
        return self._sigma

    @sigma.setter
    def sigma(self, sigma):
        """Sets the sigma of this MonteCarloRequest.


        :param sigma: The sigma of this MonteCarloRequest.  # noqa: E501
        :type: list[float]
        """

        self._sigma = sigma

    @property
    def model_id(self):
        """Gets the model_id of this MonteCarloRequest.  # noqa: E501


        :return: The model_id of this MonteCarloRequest.  # noqa: E501
        :rtype: str
        """
        return self._model_id

    @model_id.setter
    def model_id(self, model_id):
        """Sets the model_id of this MonteCarloRequest.


        :param model_id: The model_id of this MonteCarloRequest.  # noqa: E501
        :type: str
        """

        self._model_id = model_id

    @property
    def n(self):
        """Gets the n of this MonteCarloRequest.  # noqa: E501


        :return: The n of this MonteCarloRequest.  # noqa: E501
        :rtype: int
        """
        return self._n

    @n.setter
    def n(self, n):
        """Sets the n of this MonteCarloRequest.


        :param n: The n of this MonteCarloRequest.  # noqa: E501
        :type: int
        """
        if n is not None and n > 10000:  # noqa: E501
            raise ValueError("Invalid value for `n`, must be a value less than or equal to `10000`")  # noqa: E501
        if n is not None and n < 1:  # noqa: E501
            raise ValueError("Invalid value for `n`, must be a value greater than or equal to `1`")  # noqa: E501

        self._n = n

    @property
    def min_bal(self):
        """Gets the min_bal of this MonteCarloRequest.  # noqa: E501


        :return: The min_bal of this MonteCarloRequest.  # noqa: E501
        :rtype: list[float]
        """
        return self._min_bal

    @min_bal.setter
    def min_bal(self, min_bal):
        """Sets the min_bal of this MonteCarloRequest.


        :param min_bal: The min_bal of this MonteCarloRequest.  # noqa: E501
        :type: list[float]
        """

        self._min_bal = min_bal

    @property
    def frequency_interval(self):
        """Gets the frequency_interval of this MonteCarloRequest.  # noqa: E501


        :return: The frequency_interval of this MonteCarloRequest.  # noqa: E501
        :rtype: str
        """
        return self._frequency_interval

    @frequency_interval.setter
    def frequency_interval(self, frequency_interval):
        """Sets the frequency_interval of this MonteCarloRequest.


        :param frequency_interval: The frequency_interval of this MonteCarloRequest.  # noqa: E501
        :type: str
        """
        allowed_values = ["year", "six_months", "quarter", "month", "two_weeks", "week", "day"]  # noqa: E501
        if frequency_interval not in allowed_values:
            raise ValueError(
                "Invalid value for `frequency_interval` ({0}), must be one of {1}"  # noqa: E501
                .format(frequency_interval, allowed_values)
            )

        self._frequency_interval = frequency_interval

    @property
    def cf(self):
        """Gets the cf of this MonteCarloRequest.  # noqa: E501


        :return: The cf of this MonteCarloRequest.  # noqa: E501
        :rtype: list[list[float]]
        """
        return self._cf

    @cf.setter
    def cf(self, cf):
        """Sets the cf of this MonteCarloRequest.


        :param cf: The cf of this MonteCarloRequest.  # noqa: E501
        :type: list[list[float]]
        """
        if cf is None:
            raise ValueError("Invalid value for `cf`, must not be `None`")  # noqa: E501

        self._cf = cf

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(MonteCarloRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MonteCarloRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Hydrogen Proton API

    Financial engineering module of Hydrogen Atom  # noqa: E501

    OpenAPI spec version: 1.8.0
    Contact: info@hydrogenplatform.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class RecommendationConfig1(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'recommended_inflation': 'float',
        'inv_max': 'float',
        'horizon_min': 'int',
        'horizon_max': 'int',
        'dep_max': 'float',
        'inv_min': 'float',
        'dep_min': 'float'
    }

    attribute_map = {
        'recommended_inflation': 'recommended_inflation',
        'inv_max': 'inv_max',
        'horizon_min': 'horizon_min',
        'horizon_max': 'horizon_max',
        'dep_max': 'dep_max',
        'inv_min': 'inv_min',
        'dep_min': 'dep_min'
    }

    def __init__(self, recommended_inflation=0.0, inv_max=None, horizon_min=1, horizon_max=64, dep_max=None, inv_min=None, dep_min=None):  # noqa: E501
        """RecommendationConfig1 - a model defined in Swagger"""  # noqa: E501

        self._recommended_inflation = None
        self._inv_max = None
        self._horizon_min = None
        self._horizon_max = None
        self._dep_max = None
        self._inv_min = None
        self._dep_min = None
        self.discriminator = None

        if recommended_inflation is not None:
            self.recommended_inflation = recommended_inflation
        if inv_max is not None:
            self.inv_max = inv_max
        if horizon_min is not None:
            self.horizon_min = horizon_min
        if horizon_max is not None:
            self.horizon_max = horizon_max
        if dep_max is not None:
            self.dep_max = dep_max
        if inv_min is not None:
            self.inv_min = inv_min
        if dep_min is not None:
            self.dep_min = dep_min

    @property
    def recommended_inflation(self):
        """Gets the recommended_inflation of this RecommendationConfig1.  # noqa: E501


        :return: The recommended_inflation of this RecommendationConfig1.  # noqa: E501
        :rtype: float
        """
        return self._recommended_inflation

    @recommended_inflation.setter
    def recommended_inflation(self, recommended_inflation):
        """Sets the recommended_inflation of this RecommendationConfig1.


        :param recommended_inflation: The recommended_inflation of this RecommendationConfig1.  # noqa: E501
        :type: float
        """
        if recommended_inflation is not None and recommended_inflation < -1:  # noqa: E501
            raise ValueError("Invalid value for `recommended_inflation`, must be a value greater than or equal to `-1`")  # noqa: E501

        self._recommended_inflation = recommended_inflation

    @property
    def inv_max(self):
        """Gets the inv_max of this RecommendationConfig1.  # noqa: E501


        :return: The inv_max of this RecommendationConfig1.  # noqa: E501
        :rtype: float
        """
        return self._inv_max

    @inv_max.setter
    def inv_max(self, inv_max):
        """Sets the inv_max of this RecommendationConfig1.


        :param inv_max: The inv_max of this RecommendationConfig1.  # noqa: E501
        :type: float
        """
        if inv_max is not None and inv_max < 0:  # noqa: E501
            raise ValueError("Invalid value for `inv_max`, must be a value greater than or equal to `0`")  # noqa: E501

        self._inv_max = inv_max

    @property
    def horizon_min(self):
        """Gets the horizon_min of this RecommendationConfig1.  # noqa: E501


        :return: The horizon_min of this RecommendationConfig1.  # noqa: E501
        :rtype: int
        """
        return self._horizon_min

    @horizon_min.setter
    def horizon_min(self, horizon_min):
        """Sets the horizon_min of this RecommendationConfig1.


        :param horizon_min: The horizon_min of this RecommendationConfig1.  # noqa: E501
        :type: int
        """
        if horizon_min is not None and horizon_min < 0:  # noqa: E501
            raise ValueError("Invalid value for `horizon_min`, must be a value greater than or equal to `0`")  # noqa: E501

        self._horizon_min = horizon_min

    @property
    def horizon_max(self):
        """Gets the horizon_max of this RecommendationConfig1.  # noqa: E501


        :return: The horizon_max of this RecommendationConfig1.  # noqa: E501
        :rtype: int
        """
        return self._horizon_max

    @horizon_max.setter
    def horizon_max(self, horizon_max):
        """Sets the horizon_max of this RecommendationConfig1.


        :param horizon_max: The horizon_max of this RecommendationConfig1.  # noqa: E501
        :type: int
        """
        if horizon_max is not None and horizon_max < 0:  # noqa: E501
            raise ValueError("Invalid value for `horizon_max`, must be a value greater than or equal to `0`")  # noqa: E501

        self._horizon_max = horizon_max

    @property
    def dep_max(self):
        """Gets the dep_max of this RecommendationConfig1.  # noqa: E501


        :return: The dep_max of this RecommendationConfig1.  # noqa: E501
        :rtype: float
        """
        return self._dep_max

    @dep_max.setter
    def dep_max(self, dep_max):
        """Sets the dep_max of this RecommendationConfig1.


        :param dep_max: The dep_max of this RecommendationConfig1.  # noqa: E501
        :type: float
        """
        if dep_max is not None and dep_max < 0:  # noqa: E501
            raise ValueError("Invalid value for `dep_max`, must be a value greater than or equal to `0`")  # noqa: E501

        self._dep_max = dep_max

    @property
    def inv_min(self):
        """Gets the inv_min of this RecommendationConfig1.  # noqa: E501


        :return: The inv_min of this RecommendationConfig1.  # noqa: E501
        :rtype: float
        """
        return self._inv_min

    @inv_min.setter
    def inv_min(self, inv_min):
        """Sets the inv_min of this RecommendationConfig1.


        :param inv_min: The inv_min of this RecommendationConfig1.  # noqa: E501
        :type: float
        """
        if inv_min is not None and inv_min < 0:  # noqa: E501
            raise ValueError("Invalid value for `inv_min`, must be a value greater than or equal to `0`")  # noqa: E501

        self._inv_min = inv_min

    @property
    def dep_min(self):
        """Gets the dep_min of this RecommendationConfig1.  # noqa: E501


        :return: The dep_min of this RecommendationConfig1.  # noqa: E501
        :rtype: float
        """
        return self._dep_min

    @dep_min.setter
    def dep_min(self, dep_min):
        """Sets the dep_min of this RecommendationConfig1.


        :param dep_min: The dep_min of this RecommendationConfig1.  # noqa: E501
        :type: float
        """
        if dep_min is not None and dep_min < 0:  # noqa: E501
            raise ValueError("Invalid value for `dep_min`, must be a value greater than or equal to `0`")  # noqa: E501

        self._dep_min = dep_min

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(RecommendationConfig1, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RecommendationConfig1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Hydrogen Proton API

    Financial engineering module of Hydrogen Atom  # noqa: E501

    OpenAPI spec version: 1.8.0
    Contact: info@hydrogenplatform.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from proton_api.api_client import ApiClient


class SimulationsApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def backtest(self, backtest_request, **kwargs):  # noqa: E501
        """Backtest  # noqa: E501

        Run a historical analysis for a group of investments  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.backtest(backtest_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param BacktestRequest backtest_request: Request payload for Backtest (required)
        :return: dict(str, object)
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.backtest_with_http_info(backtest_request, **kwargs)  # noqa: E501
        else:
            (data) = self.backtest_with_http_info(backtest_request, **kwargs)  # noqa: E501
            return data

    def backtest_with_http_info(self, backtest_request, **kwargs):  # noqa: E501
        """Backtest  # noqa: E501

        Run a historical analysis for a group of investments  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.backtest_with_http_info(backtest_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param BacktestRequest backtest_request: Request payload for Backtest (required)
        :return: dict(str, object)
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['backtest_request']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method backtest" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'backtest_request' is set
        if ('backtest_request' not in params or
                params['backtest_request'] is None):
            raise ValueError("Missing the required parameter `backtest_request` when calling `backtest`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'backtest_request' in params:
            body_params = params['backtest_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['oauth2']  # noqa: E501

        return self.api_client.call_api(
            '/backtest', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='dict(str, object)',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def event_study(self, event_study_request, **kwargs):  # noqa: E501
        """Event Study  # noqa: E501

        Analyze a group of investments against key historical events  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.event_study(event_study_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param EventStudyRequest event_study_request: Request payload for Event Study (required)
        :return: dict(str, object)
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.event_study_with_http_info(event_study_request, **kwargs)  # noqa: E501
        else:
            (data) = self.event_study_with_http_info(event_study_request, **kwargs)  # noqa: E501
            return data

    def event_study_with_http_info(self, event_study_request, **kwargs):  # noqa: E501
        """Event Study  # noqa: E501

        Analyze a group of investments against key historical events  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.event_study_with_http_info(event_study_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param EventStudyRequest event_study_request: Request payload for Event Study (required)
        :return: dict(str, object)
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['event_study_request']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method event_study" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'event_study_request' is set
        if ('event_study_request' not in params or
                params['event_study_request'] is None):
            raise ValueError("Missing the required parameter `event_study_request` when calling `event_study`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'event_study_request' in params:
            body_params = params['event_study_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['oauth2']  # noqa: E501

        return self.api_client.call_api(
            '/event_study', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='dict(str, object)',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def monte_carlo(self, monte_carlo_request, **kwargs):  # noqa: E501
        """Monte Carlo  # noqa: E501

        Simulate the future growth of a group of investments  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.monte_carlo(monte_carlo_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param MonteCarloRequest monte_carlo_request: Request payload for Monte Carlo (required)
        :return: dict(str, object)
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.monte_carlo_with_http_info(monte_carlo_request, **kwargs)  # noqa: E501
        else:
            (data) = self.monte_carlo_with_http_info(monte_carlo_request, **kwargs)  # noqa: E501
            return data

    def monte_carlo_with_http_info(self, monte_carlo_request, **kwargs):  # noqa: E501
        """Monte Carlo  # noqa: E501

        Simulate the future growth of a group of investments  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.monte_carlo_with_http_info(monte_carlo_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param MonteCarloRequest monte_carlo_request: Request payload for Monte Carlo (required)
        :return: dict(str, object)
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['monte_carlo_request']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method monte_carlo" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'monte_carlo_request' is set
        if ('monte_carlo_request' not in params or
                params['monte_carlo_request'] is None):
            raise ValueError("Missing the required parameter `monte_carlo_request` when calling `monte_carlo`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'monte_carlo_request' in params:
            body_params = params['monte_carlo_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['oauth2']  # noqa: E501

        return self.api_client.call_api(
            '/monte_carlo', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='dict(str, object)',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def portfolio_what_if(self, portfolio_what_if_request, **kwargs):  # noqa: E501
        """Porfolio What-If  # noqa: E501

        Simulate the impact of adding, removing, reducing, or increasing various positions in a group of investments  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.portfolio_what_if(portfolio_what_if_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param PortfolioWhatIfRequest portfolio_what_if_request: Request payload for Portfolio What-If (required)
        :return: dict(str, object)
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.portfolio_what_if_with_http_info(portfolio_what_if_request, **kwargs)  # noqa: E501
        else:
            (data) = self.portfolio_what_if_with_http_info(portfolio_what_if_request, **kwargs)  # noqa: E501
            return data

    def portfolio_what_if_with_http_info(self, portfolio_what_if_request, **kwargs):  # noqa: E501
        """Porfolio What-If  # noqa: E501

        Simulate the impact of adding, removing, reducing, or increasing various positions in a group of investments  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.portfolio_what_if_with_http_info(portfolio_what_if_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param PortfolioWhatIfRequest portfolio_what_if_request: Request payload for Portfolio What-If (required)
        :return: dict(str, object)
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['portfolio_what_if_request']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method portfolio_what_if" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'portfolio_what_if_request' is set
        if ('portfolio_what_if_request' not in params or
                params['portfolio_what_if_request'] is None):
            raise ValueError("Missing the required parameter `portfolio_what_if_request` when calling `portfolio_what_if`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'portfolio_what_if_request' in params:
            body_params = params['portfolio_what_if_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['oauth2']  # noqa: E501

        return self.api_client.call_api(
            '/portfolio_what_if', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='dict(str, object)',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def savings_calculator(self, savings_calculator_request, **kwargs):  # noqa: E501
        """Savings Calculator  # noqa: E501

        Simulate the future growth of a simple savings account  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.savings_calculator(savings_calculator_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param SavingsCalculatorRequest savings_calculator_request: Request payload for Savings Calculator (required)
        :return: dict(str, object)
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.savings_calculator_with_http_info(savings_calculator_request, **kwargs)  # noqa: E501
        else:
            (data) = self.savings_calculator_with_http_info(savings_calculator_request, **kwargs)  # noqa: E501
            return data

    def savings_calculator_with_http_info(self, savings_calculator_request, **kwargs):  # noqa: E501
        """Savings Calculator  # noqa: E501

        Simulate the future growth of a simple savings account  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.savings_calculator_with_http_info(savings_calculator_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param SavingsCalculatorRequest savings_calculator_request: Request payload for Savings Calculator (required)
        :return: dict(str, object)
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['savings_calculator_request']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method savings_calculator" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'savings_calculator_request' is set
        if ('savings_calculator_request' not in params or
                params['savings_calculator_request'] is None):
            raise ValueError("Missing the required parameter `savings_calculator_request` when calling `savings_calculator`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'savings_calculator_request' in params:
            body_params = params['savings_calculator_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['oauth2']  # noqa: E501

        return self.api_client.call_api(
            '/savings_calculator', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='dict(str, object)',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def scenario_analysis(self, scneario_analysis_request, **kwargs):  # noqa: E501
        """Scenario Analysis  # noqa: E501

        Analyze a group of investments against a series of external economic factors  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.scenario_analysis(scneario_analysis_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ScenarioAnalysisRequest scneario_analysis_request: Request payload for Scenario Analysis (required)
        :return: dict(str, object)
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.scenario_analysis_with_http_info(scneario_analysis_request, **kwargs)  # noqa: E501
        else:
            (data) = self.scenario_analysis_with_http_info(scneario_analysis_request, **kwargs)  # noqa: E501
            return data

    def scenario_analysis_with_http_info(self, scneario_analysis_request, **kwargs):  # noqa: E501
        """Scenario Analysis  # noqa: E501

        Analyze a group of investments against a series of external economic factors  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.scenario_analysis_with_http_info(scneario_analysis_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ScenarioAnalysisRequest scneario_analysis_request: Request payload for Scenario Analysis (required)
        :return: dict(str, object)
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['scneario_analysis_request']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method scenario_analysis" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'scneario_analysis_request' is set
        if ('scneario_analysis_request' not in params or
                params['scneario_analysis_request'] is None):
            raise ValueError("Missing the required parameter `scneario_analysis_request` when calling `scenario_analysis`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'scneario_analysis_request' in params:
            body_params = params['scneario_analysis_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['oauth2']  # noqa: E501

        return self.api_client.call_api(
            '/scenario_analysis', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='dict(str, object)',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def sensitivity_analysis(self, sensitivity_analysis_request, **kwargs):  # noqa: E501
        """Sensitivity Analysis  # noqa: E501

        Analyze a group of investments against an external economic factor  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.sensitivity_analysis(sensitivity_analysis_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param SensitivityAnalysisRequest sensitivity_analysis_request: Request payload for Sensitivity Analysis (required)
        :return: dict(str, object)
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.sensitivity_analysis_with_http_info(sensitivity_analysis_request, **kwargs)  # noqa: E501
        else:
            (data) = self.sensitivity_analysis_with_http_info(sensitivity_analysis_request, **kwargs)  # noqa: E501
            return data

    def sensitivity_analysis_with_http_info(self, sensitivity_analysis_request, **kwargs):  # noqa: E501
        """Sensitivity Analysis  # noqa: E501

        Analyze a group of investments against an external economic factor  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.sensitivity_analysis_with_http_info(sensitivity_analysis_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param SensitivityAnalysisRequest sensitivity_analysis_request: Request payload for Sensitivity Analysis (required)
        :return: dict(str, object)
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['sensitivity_analysis_request']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method sensitivity_analysis" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'sensitivity_analysis_request' is set
        if ('sensitivity_analysis_request' not in params or
                params['sensitivity_analysis_request'] is None):
            raise ValueError("Missing the required parameter `sensitivity_analysis_request` when calling `sensitivity_analysis`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'sensitivity_analysis_request' in params:
            body_params = params['sensitivity_analysis_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['oauth2']  # noqa: E501

        return self.api_client.call_api(
            '/sensitivity_analysis', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='dict(str, object)',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Hydrogen Proton API

    The Hydrogen Proton API  # noqa: E501

    OpenAPI spec version: 1.8.0
    Contact: info@hydrogenplatform.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re

# python 2 and python 3 compatibility library
import six
import json
import urllib3
from proton_api.api_client import ApiClient


class AuthApi(object):

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def create_using_post_client_credentials(self, client_id, client_secret, **kwargs):

        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.create_using_post_client_credentials_with_http_info(client_id, client_secret, **kwargs)
        else:
            (data) = self.create_using_post_client_credentials_with_http_info(client_id, client_secret, **kwargs)
            return data

    def create_using_post_client_credentials_with_http_info(self, client_id, client_secret, **kwargs):

        query_params = {'grant_type': 'client_credentials'}
        url = re.sub('\\.com.*', '.com/authorization/v1/oauth/token', self.api_client.configuration.host)
        header_params = {
            "Authorization": urllib3.util.make_headers(basic_auth=client_id + ':' + client_secret).get('authorization')
        }

        response = self.api_client.rest_client.POST(url,
                                                    query_params=query_params,
                                                    headers=header_params,
                                                    post_params=None,
                                                    body=None)
        data = json.loads('[' + response.data + ']')
        self.access_token = data[0]["access_token"]
        return self

    def create_using_post_password_credentials(self, client_id, client_secret, username, password, **kwargs):

        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.create_using_post_password_credentials_with_http_info(client_id, client_secret, username,
                                                                              password, **kwargs)
        else:
            (data) = self.create_using_post_password_credentials_with_http_info(client_id, client_secret, username,
                                                                                password, **kwargs)
            return data

    def create_using_post_password_credentials_with_http_info(self, client_id, client_secret, username, password,
                                                              **kwargs):

        query_params = [('grant_type', 'password')]
        query_params.append(('username', username))
        query_params.append(('password', password))
        collection_formats = {}
        if query_params:
            query_params = self.api_client.sanitize_for_serialization(query_params)
            query_params = self.api_client.parameters_to_tuples(query_params,
                                                                collection_formats)

        url = re.sub('\\.com.*', '.com/authorization/v1/oauth/token', self.api_client.configuration.host)

        header_params = {
            "Authorization": urllib3.util.make_headers(basic_auth=client_id + ':' + client_secret).get('authorization')
        }

        response = self.api_client.rest_client.POST(url,
                                                    query_params=query_params,
                                                    headers=header_params,
                                                    post_params=None,
                                                    body=None)
        data = json.loads('[' + response.data + ']')
        self.access_token = data[0]["access_token"]
        return self

    def set_access_token(self, access_token):
        self.access_token = access_token
        return self

    def create_client_token_credentials(self, client_id, client_secret, client_token, **kwargs):
        url = re.sub('\\.com.*', '.com/authorization/v1/client-token', self.api_client.configuration.host);
        header_params = {
            "Authorization": urllib3.util.make_headers(basic_auth=client_id + ':' + client_secret).get('authorization'),
            "Client-Token": "Bearer " + client_token
        }
        response = self.api_client.rest_client.POST(url,
                                                    query_params=None,
                                                    headers=header_params,
                                                    post_params=None,
                                                    body=None)
        data = json.loads('[' + response.data + ']')
        self.access_token = data[0]["access_token"]
        return self



# coding: utf-8

"""
    Hydrogen Proton API

    Financial engineering module of Hydrogen Atom  # noqa: E501

    OpenAPI spec version: 1.8.0
    Contact: info@hydrogenplatform.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class GoalWithdrawalConfig(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'with_start_reference': 'str',
        'with_amount': 'float',
        'with_inflation': 'float',
        'with_start_period': 'int',
        'with_end_period': 'int',
        'with_end_reference': 'str',
        'with_frequency': 'str'
    }

    attribute_map = {
        'with_start_reference': 'with_start_reference',
        'with_amount': 'with_amount',
        'with_inflation': 'with_inflation',
        'with_start_period': 'with_start_period',
        'with_end_period': 'with_end_period',
        'with_end_reference': 'with_end_reference',
        'with_frequency': 'with_frequency'
    }

    def __init__(self, with_start_reference='a_end', with_amount=None, with_inflation=0.0, with_start_period=0, with_end_period=0, with_end_reference='d_end', with_frequency='year'):  # noqa: E501
        """GoalWithdrawalConfig - a model defined in Swagger"""  # noqa: E501

        self._with_start_reference = None
        self._with_amount = None
        self._with_inflation = None
        self._with_start_period = None
        self._with_end_period = None
        self._with_end_reference = None
        self._with_frequency = None
        self.discriminator = None

        if with_start_reference is not None:
            self.with_start_reference = with_start_reference
        if with_amount is not None:
            self.with_amount = with_amount
        if with_inflation is not None:
            self.with_inflation = with_inflation
        if with_start_period is not None:
            self.with_start_period = with_start_period
        if with_end_period is not None:
            self.with_end_period = with_end_period
        if with_end_reference is not None:
            self.with_end_reference = with_end_reference
        if with_frequency is not None:
            self.with_frequency = with_frequency

    @property
    def with_start_reference(self):
        """Gets the with_start_reference of this GoalWithdrawalConfig.  # noqa: E501


        :return: The with_start_reference of this GoalWithdrawalConfig.  # noqa: E501
        :rtype: str
        """
        return self._with_start_reference

    @with_start_reference.setter
    def with_start_reference(self, with_start_reference):
        """Sets the with_start_reference of this GoalWithdrawalConfig.


        :param with_start_reference: The with_start_reference of this GoalWithdrawalConfig.  # noqa: E501
        :type: str
        """
        allowed_values = ["a_end", "d_end"]  # noqa: E501
        if with_start_reference not in allowed_values:
            raise ValueError(
                "Invalid value for `with_start_reference` ({0}), must be one of {1}"  # noqa: E501
                .format(with_start_reference, allowed_values)
            )

        self._with_start_reference = with_start_reference

    @property
    def with_amount(self):
        """Gets the with_amount of this GoalWithdrawalConfig.  # noqa: E501


        :return: The with_amount of this GoalWithdrawalConfig.  # noqa: E501
        :rtype: float
        """
        return self._with_amount

    @with_amount.setter
    def with_amount(self, with_amount):
        """Sets the with_amount of this GoalWithdrawalConfig.


        :param with_amount: The with_amount of this GoalWithdrawalConfig.  # noqa: E501
        :type: float
        """
        if with_amount is not None and with_amount < 0:  # noqa: E501
            raise ValueError("Invalid value for `with_amount`, must be a value greater than or equal to `0`")  # noqa: E501

        self._with_amount = with_amount

    @property
    def with_inflation(self):
        """Gets the with_inflation of this GoalWithdrawalConfig.  # noqa: E501


        :return: The with_inflation of this GoalWithdrawalConfig.  # noqa: E501
        :rtype: float
        """
        return self._with_inflation

    @with_inflation.setter
    def with_inflation(self, with_inflation):
        """Sets the with_inflation of this GoalWithdrawalConfig.


        :param with_inflation: The with_inflation of this GoalWithdrawalConfig.  # noqa: E501
        :type: float
        """
        if with_inflation is not None and with_inflation < -1:  # noqa: E501
            raise ValueError("Invalid value for `with_inflation`, must be a value greater than or equal to `-1`")  # noqa: E501

        self._with_inflation = with_inflation

    @property
    def with_start_period(self):
        """Gets the with_start_period of this GoalWithdrawalConfig.  # noqa: E501


        :return: The with_start_period of this GoalWithdrawalConfig.  # noqa: E501
        :rtype: int
        """
        return self._with_start_period

    @with_start_period.setter
    def with_start_period(self, with_start_period):
        """Sets the with_start_period of this GoalWithdrawalConfig.


        :param with_start_period: The with_start_period of this GoalWithdrawalConfig.  # noqa: E501
        :type: int
        """

        self._with_start_period = with_start_period

    @property
    def with_end_period(self):
        """Gets the with_end_period of this GoalWithdrawalConfig.  # noqa: E501


        :return: The with_end_period of this GoalWithdrawalConfig.  # noqa: E501
        :rtype: int
        """
        return self._with_end_period

    @with_end_period.setter
    def with_end_period(self, with_end_period):
        """Sets the with_end_period of this GoalWithdrawalConfig.


        :param with_end_period: The with_end_period of this GoalWithdrawalConfig.  # noqa: E501
        :type: int
        """

        self._with_end_period = with_end_period

    @property
    def with_end_reference(self):
        """Gets the with_end_reference of this GoalWithdrawalConfig.  # noqa: E501


        :return: The with_end_reference of this GoalWithdrawalConfig.  # noqa: E501
        :rtype: str
        """
        return self._with_end_reference

    @with_end_reference.setter
    def with_end_reference(self, with_end_reference):
        """Sets the with_end_reference of this GoalWithdrawalConfig.


        :param with_end_reference: The with_end_reference of this GoalWithdrawalConfig.  # noqa: E501
        :type: str
        """
        allowed_values = ["a_end", "d_end"]  # noqa: E501
        if with_end_reference not in allowed_values:
            raise ValueError(
                "Invalid value for `with_end_reference` ({0}), must be one of {1}"  # noqa: E501
                .format(with_end_reference, allowed_values)
            )

        self._with_end_reference = with_end_reference

    @property
    def with_frequency(self):
        """Gets the with_frequency of this GoalWithdrawalConfig.  # noqa: E501


        :return: The with_frequency of this GoalWithdrawalConfig.  # noqa: E501
        :rtype: str
        """
        return self._with_frequency

    @with_frequency.setter
    def with_frequency(self, with_frequency):
        """Sets the with_frequency of this GoalWithdrawalConfig.


        :param with_frequency: The with_frequency of this GoalWithdrawalConfig.  # noqa: E501
        :type: str
        """
        allowed_values = ["year", "six_months", "quarter", "month", "two_weeks", "week", "day"]  # noqa: E501
        if with_frequency not in allowed_values:
            raise ValueError(
                "Invalid value for `with_frequency` ({0}), must be one of {1}"  # noqa: E501
                .format(with_frequency, allowed_values)
            )

        self._with_frequency = with_frequency

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(GoalWithdrawalConfig, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GoalWithdrawalConfig):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Hydrogen Proton API

    Financial engineering module of Hydrogen Atom  # noqa: E501

    OpenAPI spec version: 1.8.0
    Contact: info@hydrogenplatform.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class Periods(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'end': 'int',
        'start': 'int'
    }

    attribute_map = {
        'end': 'end',
        'start': 'start'
    }

    def __init__(self, end=None, start=None):  # noqa: E501
        """Periods - a model defined in Swagger"""  # noqa: E501

        self._end = None
        self._start = None
        self.discriminator = None

        if end is not None:
            self.end = end
        if start is not None:
            self.start = start

    @property
    def end(self):
        """Gets the end of this Periods.  # noqa: E501


        :return: The end of this Periods.  # noqa: E501
        :rtype: int
        """
        return self._end

    @end.setter
    def end(self, end):
        """Sets the end of this Periods.


        :param end: The end of this Periods.  # noqa: E501
        :type: int
        """
        if end is not None and end < 0:  # noqa: E501
            raise ValueError("Invalid value for `end`, must be a value greater than or equal to `0`")  # noqa: E501

        self._end = end

    @property
    def start(self):
        """Gets the start of this Periods.  # noqa: E501


        :return: The start of this Periods.  # noqa: E501
        :rtype: int
        """
        return self._start

    @start.setter
    def start(self, start):
        """Sets the start of this Periods.


        :param start: The start of this Periods.  # noqa: E501
        :type: int
        """
        if start is not None and start < 0:  # noqa: E501
            raise ValueError("Invalid value for `start`, must be a value greater than or equal to `0`")  # noqa: E501

        self._start = start

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Periods, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Periods):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Hydrogen Proton API

    Financial engineering module of Hydrogen Atom  # noqa: E501

    OpenAPI spec version: 1.8.0
    Contact: info@hydrogenplatform.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class BudgetDetails(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'frequency_unit': 'str',
        'end_date': 'date',
        'client_id': 'str',
        'budget': 'list[BudgetComponent]',
        'total_value': 'float',
        'account_id': 'str',
        'aggregation_accounts': 'list[BudgetAggregationAccount]',
        'currency_code': 'str',
        'frequency': 'int',
        'start_date': 'date'
    }

    attribute_map = {
        'frequency_unit': 'frequency_unit',
        'end_date': 'end_date',
        'client_id': 'client_id',
        'budget': 'budget',
        'total_value': 'total_value',
        'account_id': 'account_id',
        'aggregation_accounts': 'aggregation_accounts',
        'currency_code': 'currency_code',
        'frequency': 'frequency',
        'start_date': 'start_date'
    }

    def __init__(self, frequency_unit=None, end_date=None, client_id=None, budget=None, total_value=None, account_id=None, aggregation_accounts=None, currency_code=None, frequency=1, start_date=None):  # noqa: E501
        """BudgetDetails - a model defined in Swagger"""  # noqa: E501

        self._frequency_unit = None
        self._end_date = None
        self._client_id = None
        self._budget = None
        self._total_value = None
        self._account_id = None
        self._aggregation_accounts = None
        self._currency_code = None
        self._frequency = None
        self._start_date = None
        self.discriminator = None

        self.frequency_unit = frequency_unit
        if end_date is not None:
            self.end_date = end_date
        if client_id is not None:
            self.client_id = client_id
        if budget is not None:
            self.budget = budget
        if total_value is not None:
            self.total_value = total_value
        if account_id is not None:
            self.account_id = account_id
        if aggregation_accounts is not None:
            self.aggregation_accounts = aggregation_accounts
        if currency_code is not None:
            self.currency_code = currency_code
        if frequency is not None:
            self.frequency = frequency
        if start_date is not None:
            self.start_date = start_date

    @property
    def frequency_unit(self):
        """Gets the frequency_unit of this BudgetDetails.  # noqa: E501


        :return: The frequency_unit of this BudgetDetails.  # noqa: E501
        :rtype: str
        """
        return self._frequency_unit

    @frequency_unit.setter
    def frequency_unit(self, frequency_unit):
        """Sets the frequency_unit of this BudgetDetails.


        :param frequency_unit: The frequency_unit of this BudgetDetails.  # noqa: E501
        :type: str
        """
        if frequency_unit is None:
            raise ValueError("Invalid value for `frequency_unit`, must not be `None`")  # noqa: E501
        allowed_values = ["daily", "weekly", "bi-weekly", "monthly", "quarterly", "annually"]  # noqa: E501
        if frequency_unit not in allowed_values:
            raise ValueError(
                "Invalid value for `frequency_unit` ({0}), must be one of {1}"  # noqa: E501
                .format(frequency_unit, allowed_values)
            )

        self._frequency_unit = frequency_unit

    @property
    def end_date(self):
        """Gets the end_date of this BudgetDetails.  # noqa: E501


        :return: The end_date of this BudgetDetails.  # noqa: E501
        :rtype: date
        """
        return self._end_date

    @end_date.setter
    def end_date(self, end_date):
        """Sets the end_date of this BudgetDetails.


        :param end_date: The end_date of this BudgetDetails.  # noqa: E501
        :type: date
        """

        self._end_date = end_date

    @property
    def client_id(self):
        """Gets the client_id of this BudgetDetails.  # noqa: E501


        :return: The client_id of this BudgetDetails.  # noqa: E501
        :rtype: str
        """
        return self._client_id

    @client_id.setter
    def client_id(self, client_id):
        """Sets the client_id of this BudgetDetails.


        :param client_id: The client_id of this BudgetDetails.  # noqa: E501
        :type: str
        """

        self._client_id = client_id

    @property
    def budget(self):
        """Gets the budget of this BudgetDetails.  # noqa: E501


        :return: The budget of this BudgetDetails.  # noqa: E501
        :rtype: list[BudgetComponent]
        """
        return self._budget

    @budget.setter
    def budget(self, budget):
        """Sets the budget of this BudgetDetails.


        :param budget: The budget of this BudgetDetails.  # noqa: E501
        :type: list[BudgetComponent]
        """

        self._budget = budget

    @property
    def total_value(self):
        """Gets the total_value of this BudgetDetails.  # noqa: E501


        :return: The total_value of this BudgetDetails.  # noqa: E501
        :rtype: float
        """
        return self._total_value

    @total_value.setter
    def total_value(self, total_value):
        """Sets the total_value of this BudgetDetails.


        :param total_value: The total_value of this BudgetDetails.  # noqa: E501
        :type: float
        """
        if total_value is not None and total_value < 0:  # noqa: E501
            raise ValueError("Invalid value for `total_value`, must be a value greater than or equal to `0`")  # noqa: E501

        self._total_value = total_value

    @property
    def account_id(self):
        """Gets the account_id of this BudgetDetails.  # noqa: E501


        :return: The account_id of this BudgetDetails.  # noqa: E501
        :rtype: str
        """
        return self._account_id

    @account_id.setter
    def account_id(self, account_id):
        """Sets the account_id of this BudgetDetails.


        :param account_id: The account_id of this BudgetDetails.  # noqa: E501
        :type: str
        """

        self._account_id = account_id

    @property
    def aggregation_accounts(self):
        """Gets the aggregation_accounts of this BudgetDetails.  # noqa: E501


        :return: The aggregation_accounts of this BudgetDetails.  # noqa: E501
        :rtype: list[BudgetAggregationAccount]
        """
        return self._aggregation_accounts

    @aggregation_accounts.setter
    def aggregation_accounts(self, aggregation_accounts):
        """Sets the aggregation_accounts of this BudgetDetails.


        :param aggregation_accounts: The aggregation_accounts of this BudgetDetails.  # noqa: E501
        :type: list[BudgetAggregationAccount]
        """

        self._aggregation_accounts = aggregation_accounts

    @property
    def currency_code(self):
        """Gets the currency_code of this BudgetDetails.  # noqa: E501


        :return: The currency_code of this BudgetDetails.  # noqa: E501
        :rtype: str
        """
        return self._currency_code

    @currency_code.setter
    def currency_code(self, currency_code):
        """Sets the currency_code of this BudgetDetails.


        :param currency_code: The currency_code of this BudgetDetails.  # noqa: E501
        :type: str
        """

        self._currency_code = currency_code

    @property
    def frequency(self):
        """Gets the frequency of this BudgetDetails.  # noqa: E501


        :return: The frequency of this BudgetDetails.  # noqa: E501
        :rtype: int
        """
        return self._frequency

    @frequency.setter
    def frequency(self, frequency):
        """Sets the frequency of this BudgetDetails.


        :param frequency: The frequency of this BudgetDetails.  # noqa: E501
        :type: int
        """
        if frequency is not None and frequency < 1:  # noqa: E501
            raise ValueError("Invalid value for `frequency`, must be a value greater than or equal to `1`")  # noqa: E501

        self._frequency = frequency

    @property
    def start_date(self):
        """Gets the start_date of this BudgetDetails.  # noqa: E501


        :return: The start_date of this BudgetDetails.  # noqa: E501
        :rtype: date
        """
        return self._start_date

    @start_date.setter
    def start_date(self, start_date):
        """Sets the start_date of this BudgetDetails.


        :param start_date: The start_date of this BudgetDetails.  # noqa: E501
        :type: date
        """

        self._start_date = start_date

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(BudgetDetails, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BudgetDetails):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Hydrogen Proton API

    Financial engineering module of Hydrogen Atom  # noqa: E501

    OpenAPI spec version: 1.8.0
    Contact: info@hydrogenplatform.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class EducationCalculatorPercentCoveredRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'aggregation_account_ids': 'list[str]',
        'total_annual_cost': 'float',
        'tax_rate': 'float',
        'account_ids': 'list[str]',
        'initial_balance': 'float',
        'decumulation_horizon': 'int',
        'accumulation_horizon': 'int',
        'education_inflation_rate': 'float',
        'portfolio_return': 'float',
        'deposit_schedule': 'CalculatorDepositSchedule1',
        'general_inflation_rate': 'float'
    }

    attribute_map = {
        'aggregation_account_ids': 'aggregation_account_ids',
        'total_annual_cost': 'total_annual_cost',
        'tax_rate': 'tax_rate',
        'account_ids': 'account_ids',
        'initial_balance': 'initial_balance',
        'decumulation_horizon': 'decumulation_horizon',
        'accumulation_horizon': 'accumulation_horizon',
        'education_inflation_rate': 'education_inflation_rate',
        'portfolio_return': 'portfolio_return',
        'deposit_schedule': 'deposit_schedule',
        'general_inflation_rate': 'general_inflation_rate'
    }

    def __init__(self, aggregation_account_ids=None, total_annual_cost=None, tax_rate=0.0, account_ids=None, initial_balance=0.0, decumulation_horizon=None, accumulation_horizon=None, education_inflation_rate=0.05, portfolio_return=None, deposit_schedule=None, general_inflation_rate=0.0):  # noqa: E501
        """EducationCalculatorPercentCoveredRequest - a model defined in Swagger"""  # noqa: E501

        self._aggregation_account_ids = None
        self._total_annual_cost = None
        self._tax_rate = None
        self._account_ids = None
        self._initial_balance = None
        self._decumulation_horizon = None
        self._accumulation_horizon = None
        self._education_inflation_rate = None
        self._portfolio_return = None
        self._deposit_schedule = None
        self._general_inflation_rate = None
        self.discriminator = None

        if aggregation_account_ids is not None:
            self.aggregation_account_ids = aggregation_account_ids
        self.total_annual_cost = total_annual_cost
        if tax_rate is not None:
            self.tax_rate = tax_rate
        if account_ids is not None:
            self.account_ids = account_ids
        if initial_balance is not None:
            self.initial_balance = initial_balance
        self.decumulation_horizon = decumulation_horizon
        self.accumulation_horizon = accumulation_horizon
        if education_inflation_rate is not None:
            self.education_inflation_rate = education_inflation_rate
        self.portfolio_return = portfolio_return
        if deposit_schedule is not None:
            self.deposit_schedule = deposit_schedule
        if general_inflation_rate is not None:
            self.general_inflation_rate = general_inflation_rate

    @property
    def aggregation_account_ids(self):
        """Gets the aggregation_account_ids of this EducationCalculatorPercentCoveredRequest.  # noqa: E501


        :return: The aggregation_account_ids of this EducationCalculatorPercentCoveredRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._aggregation_account_ids

    @aggregation_account_ids.setter
    def aggregation_account_ids(self, aggregation_account_ids):
        """Sets the aggregation_account_ids of this EducationCalculatorPercentCoveredRequest.


        :param aggregation_account_ids: The aggregation_account_ids of this EducationCalculatorPercentCoveredRequest.  # noqa: E501
        :type: list[str]
        """

        self._aggregation_account_ids = aggregation_account_ids

    @property
    def total_annual_cost(self):
        """Gets the total_annual_cost of this EducationCalculatorPercentCoveredRequest.  # noqa: E501


        :return: The total_annual_cost of this EducationCalculatorPercentCoveredRequest.  # noqa: E501
        :rtype: float
        """
        return self._total_annual_cost

    @total_annual_cost.setter
    def total_annual_cost(self, total_annual_cost):
        """Sets the total_annual_cost of this EducationCalculatorPercentCoveredRequest.


        :param total_annual_cost: The total_annual_cost of this EducationCalculatorPercentCoveredRequest.  # noqa: E501
        :type: float
        """
        if total_annual_cost is None:
            raise ValueError("Invalid value for `total_annual_cost`, must not be `None`")  # noqa: E501
        if total_annual_cost is not None and total_annual_cost < 0:  # noqa: E501
            raise ValueError("Invalid value for `total_annual_cost`, must be a value greater than or equal to `0`")  # noqa: E501

        self._total_annual_cost = total_annual_cost

    @property
    def tax_rate(self):
        """Gets the tax_rate of this EducationCalculatorPercentCoveredRequest.  # noqa: E501


        :return: The tax_rate of this EducationCalculatorPercentCoveredRequest.  # noqa: E501
        :rtype: float
        """
        return self._tax_rate

    @tax_rate.setter
    def tax_rate(self, tax_rate):
        """Sets the tax_rate of this EducationCalculatorPercentCoveredRequest.


        :param tax_rate: The tax_rate of this EducationCalculatorPercentCoveredRequest.  # noqa: E501
        :type: float
        """
        if tax_rate is not None and tax_rate > 1:  # noqa: E501
            raise ValueError("Invalid value for `tax_rate`, must be a value less than or equal to `1`")  # noqa: E501
        if tax_rate is not None and tax_rate < 0:  # noqa: E501
            raise ValueError("Invalid value for `tax_rate`, must be a value greater than or equal to `0`")  # noqa: E501

        self._tax_rate = tax_rate

    @property
    def account_ids(self):
        """Gets the account_ids of this EducationCalculatorPercentCoveredRequest.  # noqa: E501


        :return: The account_ids of this EducationCalculatorPercentCoveredRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._account_ids

    @account_ids.setter
    def account_ids(self, account_ids):
        """Sets the account_ids of this EducationCalculatorPercentCoveredRequest.


        :param account_ids: The account_ids of this EducationCalculatorPercentCoveredRequest.  # noqa: E501
        :type: list[str]
        """

        self._account_ids = account_ids

    @property
    def initial_balance(self):
        """Gets the initial_balance of this EducationCalculatorPercentCoveredRequest.  # noqa: E501


        :return: The initial_balance of this EducationCalculatorPercentCoveredRequest.  # noqa: E501
        :rtype: float
        """
        return self._initial_balance

    @initial_balance.setter
    def initial_balance(self, initial_balance):
        """Sets the initial_balance of this EducationCalculatorPercentCoveredRequest.


        :param initial_balance: The initial_balance of this EducationCalculatorPercentCoveredRequest.  # noqa: E501
        :type: float
        """
        if initial_balance is not None and initial_balance < 0:  # noqa: E501
            raise ValueError("Invalid value for `initial_balance`, must be a value greater than or equal to `0`")  # noqa: E501

        self._initial_balance = initial_balance

    @property
    def decumulation_horizon(self):
        """Gets the decumulation_horizon of this EducationCalculatorPercentCoveredRequest.  # noqa: E501


        :return: The decumulation_horizon of this EducationCalculatorPercentCoveredRequest.  # noqa: E501
        :rtype: int
        """
        return self._decumulation_horizon

    @decumulation_horizon.setter
    def decumulation_horizon(self, decumulation_horizon):
        """Sets the decumulation_horizon of this EducationCalculatorPercentCoveredRequest.


        :param decumulation_horizon: The decumulation_horizon of this EducationCalculatorPercentCoveredRequest.  # noqa: E501
        :type: int
        """
        if decumulation_horizon is None:
            raise ValueError("Invalid value for `decumulation_horizon`, must not be `None`")  # noqa: E501
        if decumulation_horizon is not None and decumulation_horizon < 0:  # noqa: E501
            raise ValueError("Invalid value for `decumulation_horizon`, must be a value greater than or equal to `0`")  # noqa: E501

        self._decumulation_horizon = decumulation_horizon

    @property
    def accumulation_horizon(self):
        """Gets the accumulation_horizon of this EducationCalculatorPercentCoveredRequest.  # noqa: E501


        :return: The accumulation_horizon of this EducationCalculatorPercentCoveredRequest.  # noqa: E501
        :rtype: int
        """
        return self._accumulation_horizon

    @accumulation_horizon.setter
    def accumulation_horizon(self, accumulation_horizon):
        """Sets the accumulation_horizon of this EducationCalculatorPercentCoveredRequest.


        :param accumulation_horizon: The accumulation_horizon of this EducationCalculatorPercentCoveredRequest.  # noqa: E501
        :type: int
        """
        if accumulation_horizon is None:
            raise ValueError("Invalid value for `accumulation_horizon`, must not be `None`")  # noqa: E501
        if accumulation_horizon is not None and accumulation_horizon < 0:  # noqa: E501
            raise ValueError("Invalid value for `accumulation_horizon`, must be a value greater than or equal to `0`")  # noqa: E501

        self._accumulation_horizon = accumulation_horizon

    @property
    def education_inflation_rate(self):
        """Gets the education_inflation_rate of this EducationCalculatorPercentCoveredRequest.  # noqa: E501


        :return: The education_inflation_rate of this EducationCalculatorPercentCoveredRequest.  # noqa: E501
        :rtype: float
        """
        return self._education_inflation_rate

    @education_inflation_rate.setter
    def education_inflation_rate(self, education_inflation_rate):
        """Sets the education_inflation_rate of this EducationCalculatorPercentCoveredRequest.


        :param education_inflation_rate: The education_inflation_rate of this EducationCalculatorPercentCoveredRequest.  # noqa: E501
        :type: float
        """
        if education_inflation_rate is not None and education_inflation_rate < -1:  # noqa: E501
            raise ValueError("Invalid value for `education_inflation_rate`, must be a value greater than or equal to `-1`")  # noqa: E501

        self._education_inflation_rate = education_inflation_rate

    @property
    def portfolio_return(self):
        """Gets the portfolio_return of this EducationCalculatorPercentCoveredRequest.  # noqa: E501


        :return: The portfolio_return of this EducationCalculatorPercentCoveredRequest.  # noqa: E501
        :rtype: float
        """
        return self._portfolio_return

    @portfolio_return.setter
    def portfolio_return(self, portfolio_return):
        """Sets the portfolio_return of this EducationCalculatorPercentCoveredRequest.


        :param portfolio_return: The portfolio_return of this EducationCalculatorPercentCoveredRequest.  # noqa: E501
        :type: float
        """
        if portfolio_return is None:
            raise ValueError("Invalid value for `portfolio_return`, must not be `None`")  # noqa: E501
        if portfolio_return is not None and portfolio_return < -1:  # noqa: E501
            raise ValueError("Invalid value for `portfolio_return`, must be a value greater than or equal to `-1`")  # noqa: E501

        self._portfolio_return = portfolio_return

    @property
    def deposit_schedule(self):
        """Gets the deposit_schedule of this EducationCalculatorPercentCoveredRequest.  # noqa: E501


        :return: The deposit_schedule of this EducationCalculatorPercentCoveredRequest.  # noqa: E501
        :rtype: CalculatorDepositSchedule1
        """
        return self._deposit_schedule

    @deposit_schedule.setter
    def deposit_schedule(self, deposit_schedule):
        """Sets the deposit_schedule of this EducationCalculatorPercentCoveredRequest.


        :param deposit_schedule: The deposit_schedule of this EducationCalculatorPercentCoveredRequest.  # noqa: E501
        :type: CalculatorDepositSchedule1
        """

        self._deposit_schedule = deposit_schedule

    @property
    def general_inflation_rate(self):
        """Gets the general_inflation_rate of this EducationCalculatorPercentCoveredRequest.  # noqa: E501


        :return: The general_inflation_rate of this EducationCalculatorPercentCoveredRequest.  # noqa: E501
        :rtype: float
        """
        return self._general_inflation_rate

    @general_inflation_rate.setter
    def general_inflation_rate(self, general_inflation_rate):
        """Sets the general_inflation_rate of this EducationCalculatorPercentCoveredRequest.


        :param general_inflation_rate: The general_inflation_rate of this EducationCalculatorPercentCoveredRequest.  # noqa: E501
        :type: float
        """
        if general_inflation_rate is not None and general_inflation_rate < -1:  # noqa: E501
            raise ValueError("Invalid value for `general_inflation_rate`, must be a value greater than or equal to `-1`")  # noqa: E501

        self._general_inflation_rate = general_inflation_rate

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(EducationCalculatorPercentCoveredRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, EducationCalculatorPercentCoveredRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
